@@ -2,12 +2,12 @@
                                                   var,
                                                   Y, X0, X, Z, 
                                                   nT0basis,
-                                                  Spline_t0=MSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE), Intercept_t0=TRUE,
+                                                  Spline_t0=BSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE), Intercept_t0=TRUE,
                                                   ialpha0, nX0,
                                                   ibeta0, nX,
                                                   ialpha, ibeta,
                                                   nTbasis,
-                                                  Spline_t =MSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE),
+                                                  Spline_t =BSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE),
                                                   listZSplineBasis,
                                                   Intercept_t_NPH=rep(TRUE, nX), 
                                                   bhlink=c("log", "identity"),
