@@ -5,12 +5,12 @@ opg_flexrsurv_fromto_G0A0B0AB_bh<-function(GA0B0AB, Y, X0, X, Z,
                                intTD=intTD_NC, intweightsfunc=intweights_CAV_SIM,
                                intTD_base=intTD_base_NC,
                                nT0basis,
-                               Spline_t0=MSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE), Intercept_t0=TRUE,
+                               Spline_t0=BSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE), Intercept_t0=TRUE,
                                ialpha0, nX0,
                                ibeta0, nX,
                                ialpha, ibeta,                             
                                nTbasis,
-                               Spline_t =MSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE),
+                               Spline_t =BSplineBasis(knots=NULL,  degree=3,   keep.duplicates=TRUE),
                       Intercept_t_NPH=rep(TRUE, nX),
                                                      debug.gr=FALSE,  ...){
   # compute the outer product of the gradient to estimate Fisher Information (expected informataion matrix) for Type I censoring
@@ -109,13 +109,13 @@ YT0Gamma0 <- predictSpline(Spline_t0*tmpgamma0, Y[,2], intercept=Intercept_t0)
   }
   
   if(nX + nZ) {
-    NPHterm <- intTD(rateTD_bh_alphabeta, fromT=Y[,1], toT=Y[,2], fail=Y[,3],
+    NPHterm <- intTD(rateTD_bh_alphabeta, intFrom=Y[,1], intTo=Y[,2], intToStatus=Y[,3],
                      step=step, Nstep=Nstep,
                      intweightsfunc=intweightsfunc, 
                      gamma0=GA0B0AB[1:nT0basis], Zalphabeta=Zalphabeta, 
                      Spline_t0=Spline_t0*tmpgamma0, Intercept_t0=Intercept_t0,
                      Spline_t = Spline_t, Intercept_t=TRUE)
-    Intb0 <-  intTD_base(func=ratioTD_bh_alphabeta, fromT=Y[,1], toT=Y[,2], fail=Y[,3],
+    Intb0 <-  intTD_base(func=ratioTD_bh_alphabeta, intFrom=Y[,1], intTo=Y[,2], intToStatus=Y[,3],
                          Spline=Spline_t0,
                          step=step, Nstep=Nstep, 
                          intweightsfunc=intweightsfunc, 
@@ -123,7 +123,7 @@ YT0Gamma0 <- predictSpline(Spline_t0*tmpgamma0, Y[,2], intercept=Intercept_t0)
                          Spline_t0=Spline_t0*tmpgamma0, Intercept_t0=Intercept_t0,
                          Spline_t = Spline_t, Intercept_t=TRUE,
                          debug=debug.gr)
-    Intb <-  intTD_base(func=rateTD_bh_alphabeta, fromT=Y[,1], toT=Y[,2], fail=Y[,3],
+    Intb <-  intTD_base(func=rateTD_bh_alphabeta, intFrom=Y[,1], intTo=Y[,2], intToStatus=Y[,3],
                           Spline=Spline_t,
                           step=step, Nstep=Nstep, 
                           intweightsfunc=intweightsfunc,
@@ -145,7 +145,7 @@ YT0Gamma0 <- predictSpline(Spline_t0*tmpgamma0, Y[,2], intercept=Intercept_t0)
                        0)
   }
   else {
-#    NPHterm <- intTD(rateTD_bh, fromT=Y[,1], toT=Y[,2], fail=Y[,3],
+#    NPHterm <- intTD(rateTD_gamma0_bh,  intFrom=Y[,1], intTo=Y[,2], intToStatus=Y[,3],
 #                     step=step, Nstep=Nstep, intweightsfunc=intweightsfunc, 
 #                     gamma0=GA0B0AB[1:nT0basis],
 #                     Spline_t0=Spline_t0, Intercept_t0=Intercept_t0)
