@@ -102,7 +102,7 @@ rateTD<- function(T, iT, ... ){
 
 # computes the contribution of time dependent termes in the rate (baseline, NPH, NPHNLL and WCE effects 
 rateTD_gamma0alphabetaeta0<- function(T, iT,
-                                      fromT, toT, fail, FirstId,
+                                      fromT, toT, FirstId, LastId,
                                       gamma0, Zalphabeta,
                                       nW, W, eta0, iWbeg, iWend,
                       Spline_t0=SplineBasis(knots=NULL,  order=4,   keep.duplicates=TRUE), Intercept_t0=TRUE,
@@ -113,15 +113,14 @@ rateTD_gamma0alphabetaeta0<- function(T, iT,
   # at a vector of T (useful to compute numerical integration
   # fromT : begining of the time intervals
   # toT   : end of the time intervals
-  # fail  : fail = 1 if event, 0 if censored
   # all T basis for the NPH/td effects are the same (Spline_t)
   # Zalphabeta = X %*% beta0 + f(Z,alpha) %*% beta 
-  # FirstId : all lines in FirstId[iT]:iT of fromT, toT, fail and Zalphabeta comes from the same individual 
+  # FirstId : all lines in FirstId[iT]:iT of fromT, toT, and Zalphabeta comes from the same individual 
   # nW number of cols in W (number of WCE effects
   # W matrix of exposure INCREMENT variables W[FirstId[iT]:iT, k] is the vectore of exposure increment x_il - x_(i-1)l for patient l, expo variable k    
   # eta0 : vector all the coef of WCE
   # iWbeg, iWend : coef of the ith WCE variable is eta0[iWbeg[i]:iWend[i]]
-  # ISpline_W : list of the nW integrated splines parameters for the WCE effects multiplied by eta0
+  # ISpline_W : list of the nW integrated splines parameters for the WCE effects scaled by eta0
   #           : thus no nead to multiply each spline coordinate by its coef
   # Spline_t0 : splines parameters for the baseline hazard multiplied by gamma0
   #           : thus no nead to multiply each spline coordinate by its coef
@@ -134,9 +133,13 @@ rateTD_gamma0alphabetaeta0<- function(T, iT,
 
 
     for(iW in 1:nW){
-      for(iId in FirstId[iT]:iT){
-        WCE <- WCE + W[iId, iW] * predictSpline(ISpline_W[[iW]], T-fromT[iId], intercept=Intercept_W[[iW]], outer.ok=TRUE)  
-      }
+      wce <- predictwce(object=ISpline_W[[iW]], t=T, Increment=W[,iW], fromT=fromT, tId=rep(iT, length(T)),
+                           FirstId=FirstId, LastId=LastId, intercept=Intercept_W, outer.ok=TRUE)
+      WCE = WCE + wce
+
+#      for(iId in FirstId[iT]:iT){
+#        WCE <- WCE + W[iId, iW] * predictSpline(ISpline_W[[iW]], T-fromT[iId], intercept=Intercept_W[[iW]], outer.ok=TRUE)  
+#      }
     }
   # returned value 
   exp(WCE + YT %*% Zalphabeta[iT,])
@@ -147,43 +150,77 @@ rateTD_gamma0alphabetaeta0<- function(T, iT,
 
 # computes the contribution of gamma0 and eta0 (baseline & WCE)
 rateTD_gamma0eta0<- function(T, iT,
-                                      fromT, FirstId,
-                                      gamma0, 
-                                      nW, W, eta0, iWbeg, iWend,
-                      Spline_t0=SplineBasis(knots=NULL,  order=4,   keep.duplicates=TRUE), Intercept_t0=TRUE,
-                                      ISpline_W, Intercept_W=rep(TRUE,nW), ...){
+                             fromT, FirstId, LastId,
+                             gamma0, 
+                             nW, W, 
+                             Spline_t0=SplineBasis(knots=NULL,  order=4,   keep.duplicates=TRUE), Intercept_t0=TRUE,
+                             ISpline_W, Intercept_W=rep(TRUE,nW), ...){
   # compute the contribution of the time dependent variables to the rate 
   # of relative survival model for patient iT 
   # at a vector of T (useful to compute numerical integration
   # fromT : begining of the time intervals
   # toT   : end of the time intervals
-  # fail  : fail = 1 if event, 0 if censored
-  # FirstId : all lines in FirstId[iT]:iT of fromT, toT, fail and Zalphabeta comes from the same individual 
+  # FirstId : all lines in FirstId[iT]:iT of fromT, toT, and Zalphabeta comes from the same individual 
  # nW number of cols in W (number of WCE effects
   # W matrix of exposure INCREMENT variables W[FirstId[iT]:iT, k] is the vectore of exposure increment x_il - x_(i-1)l for patient l, expo variable k    
   # eta0 : vector all the coef of WCE
   # iWbeg, iWend : coef of the ith WCE variable is eta0[iWbeg[i]:iWend[i]]
-  # ISpline_W : list of the nW integrated splines parameters for the WCE effects multiplied by eta0
+  # ISpline_W : list of the nW integrated splines parameters for the WCE effects SCALED by eta0
   #           : thus no nead to multiply each spline coordinate by its coef
   # Spline_t0 : splines parameters for the baseline hazard multiplied by gamma0
   #           : thus no nead to multiply each spline coordinate by its coef
 
 #  print("rateTD_gamma0eta0")
   
-  # spline bases for baseline hazard
-#  cat("************************************************************************\niT, T, first: ")
-#  cat(c(iT, FirstId[iT], T))
-#  cat("\n")
       
     WCE <- predictSpline(Spline_t0, T, intercept=Intercept_t0, outer.ok=TRUE)
     for(iW in 1:nW){
-      for(iId in FirstId[iT]:iT){
-#  cat("iId, W[Iid, iW], fromT[iId]: ")
-#  cat(c(iId, W[iId, iW], fromT[iId]))
-#  cat("\n")
-#  print(cbind(T, predictSpline(ISpline_W[[iW]], T-fromT[iId], intercept=Intercept_W[[iW]], outer.ok=TRUE)))
-        WCE <- WCE + W[iId, iW] * predictSpline(ISpline_W[[iW]], T-fromT[iId], intercept=Intercept_W[[iW]], outer.ok=TRUE)  
-      }
+      wce <- predictwce(object=ISpline_W[[iW]], t=T, Increment=W[,iW], fromT=fromT, tId=rep(iT, length(T)),
+                        FirstId=FirstId, LastId=LastId, intercept=Intercept_W, outer.ok=TRUE)
+      WCE = WCE + wce
+       
+#       for(iId in FirstId[iT]:iT){
+#         WCE <- WCE + W[iId, iW] * predictSpline(ISpline_W[[iW]], T-fromT[iId], intercept=Intercept_W[[iW]], outer.ok=TRUE)  
+#       }
+    }
+  exp(WCE)
+  
+}
+
+
+
+# computes the contribution eta0 (WCE)
+rateTD_eta0<- function(T, iT,
+                       fromT, FirstId, LastId,
+                       nW, W, 
+                       ISpline_W, Intercept_W=rep(TRUE,nW), ...){
+  # compute the contribution of the time dependent variables to the rate 
+  # of relative survival model for patient iT 
+  # at a vector of T (useful to compute numerical integration
+  # fromT : begining of the time intervals
+  # toT   : end of the time intervals
+  # FirstId : all lines in FirstId[iT]:iT of fromT, toT, and Zalphabeta comes from the same individual 
+ # nW number of cols in W (number of WCE effects
+  # W matrix of exposure INCREMENT variables W[FirstId[iT]:iT, k] is the vectore of exposure increment x_il - x_(i-1)l for patient l, expo variable k    
+  # eta0 : vector all the coef of WCE
+  # iWbeg, iWend : coef of the ith WCE variable is eta0[iWbeg[i]:iWend[i]]
+  # ISpline_W : list of the nW integrated splines parameters for the WCE effects SCALED by eta0
+  #           : thus no nead to multiply each spline coordinate by its coef
+
+#  print("rateTD_eta0")
+  
+      
+    WCE <- predictwce(object=ISpline_W[[1]], t=T, Increment=W[,1], fromT=fromT, tId=rep(iT, length(T)),
+                           FirstId=FirstId, LastId=LastId, intercept=Intercept_W, outer.ok=TRUE)
+    iW <- 2
+    while(iW <=nW){
+      wce <- predictwce(object=ISpline_W[[iW]], t=T, Increment=W[,iW], fromT=fromT, tId=rep(iT, length(T)),
+                        FirstId=FirstId, LastId=LastId, intercept=Intercept_W, outer.ok=TRUE)
+      WCE = WCE + wce
+#      for(iId in FirstId[iT]:iT){
+#        WCE <- WCE + W[iId, iW] * predictSpline(ISpline_W[[iW]], T-fromT[iId], intercept=Intercept_W[[iW]], outer.ok=TRUE)  
+#      }
+       iW <- iW+1
     }
   # returned value
   exp(WCE)
@@ -195,3 +232,65 @@ rateTD_gamma0eta0<- function(T, iT,
 
 
 
+# computes the contribution of time dependent termes in the rate of additive proportionamle WCE model (WCE, NPH, NPHNLL)
+rateTD_alphabeta_1addwce<- function(T, iT,
+                                      fromT, toT, FirstId, LastId,
+                                      Zalphabeta,
+                                      W, 
+                                        Spline_t =SplineBasis(knots=NULL,  order=4,   keep.duplicates=TRUE), Intercept_t=TRUE,
+                                      ISpline_W, Intercept_W=TRUE, ...){
+  # compute the contribution of the time dependent variables to the rate WCE(W,T)*exp(NPH + NPHNLL)
+  # of relative survival model for line iT with Zalphabeta[iT, ]
+  # at a vector of T (useful to compute numerical integration
+  # fromT : begining of the time intervals
+  # toT   : end of the time intervals
+  # all T basis for the NPH/td effects are the same (Spline_t)
+  # Zalphabeta = X %*% beta0 + f(Z,alpha) %*% beta 
+  # FirstId : all lines in FirstId[iT]:iT of fromT, toT, and Zalphabeta comes from the same individual 
+  # W vecteur of exposure INCREMENT variables W[FirstId[iT]:iT] is the vectore of exposure increment x_il - x_(i-1)l for patient l
+  # eta0 : vector all the coef of WCE
+  # iWbeg, iWend : coef of the ith WCE variable is eta0[iWbeg[i]:iWend[i]]
+  # ISpline_W : a single integrated splines parameters for the WCE effects scaled by eta0
+  #           : thus no nead to multiply each spline coordinate by its coef
+
+#  print("rateTD_alphabeta_1addwceeta0")
+  # spline bases for baseline hazard
+    WCE <- predictwce(object=ISpline_W, t=T, Increment=W, fromT=fromT, tId=rep(iT, length(T)),
+                           FirstId=FirstId, LastId=LastId, intercept=Intercept_W, outer.ok=TRUE)
+  # spline bases for each TD effect
+#    YT <- fevaluate(Spline_t, T, intercept=Intercept_t, outer.ok=TRUE)
+    YT <- evaluatelc(Spline_t, T, Zalphabeta[iT,], intercept=Intercept_t, outer.ok=TRUE)
+
+
+  # returned value 
+#  WCE * exp(YT %*% Zalphabeta[iT,])
+  WCE * exp(YT)
+  
+}
+
+# computes the contribution of additive proportionamle WCE model (no NPH, NPHNLL)
+rateTD_1addwce<- function(T, iT,
+                              fromT, toT, FirstId, LastId,
+                              W, 
+                              ISpline_W, Intercept_W=TRUE, ...){
+  # compute the contribution of the time dependent variables to the rate WCE(W,T)*exp(NPH + NPHNLL)
+  # of relative survival model for line iT with Zalphabeta[iT, ]
+  # at a vector of T (useful to compute numerical integration
+  # fromT : begining of the time intervals
+  # toT   : end of the time intervals
+  # all T basis for the NPH/td effects are the same (Spline_t)
+  # Zalphabeta = X %*% beta0 + f(Z,alpha) %*% beta 
+  # FirstId : all lines in FirstId[iT]:iT of fromT, toT, and Zalphabeta comes from the same individual 
+  # W vecteur of exposure INCREMENT variables W[FirstId[iT]:iT] is the vectore of exposure increment x_il - x_(i-1)l for patient l
+  # eta0 : vector all the coef of WCE
+  # iWbeg, iWend : coef of the ith WCE variable is eta0[iWbeg[i]:iWend[i]]
+  # ISpline_W : a single integrated splines parameters for the WCE effects scaled by eta0
+  #           : thus no nead to multiply each spline coordinate by its coef
+
+#  print("rateTD_alphabeta_1addwceeta0")
+  # spline bases for baseline hazard
+    predictwce(object=ISpline_W, t=T, Increment=W, fromT=fromT, tId=rep(iT, length(T)),
+                           FirstId=FirstId, LastId=LastId, intercept=Intercept_W, outer.ok=TRUE)
+  
+}
+
